import time

# Import the preset TestFixture.
from .Frames_trasnmission_fixture import FixtureFramesTrasnmission, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestLinTransmitter(FixtureFramesTrasnmission):

    # This method will be executed just before
    # the test case method execution.
    def setUp(self):
        logger.info("setup test case")

    # This method will be executed just after
    # the test case method execution.
    def tearDown(self):
        logger.info("tear down test case")

    # Create the test case method that holds the main test steps.
    def test_lin_transmitter(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual in vehicle communication.
        channel_name = 'B1_LIN'
        frame_id = '0x30'
        payload = [0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF]

        lin_ch = ChannelFactory().get_lin_channel(channel_name)

        lin_fr = lin_ch.get_frame(frame_id)

        # Log any useful message
        logger.info("create and transmit a lin frame")

        # Transmit a lin frame
        lin_transmit = lin_fr.transmitter.transmit_frame(payload)

        time.sleep(2)

        # Confirm the correct transmission by verifying
        # the boolean return value of transmit_frame().
        # If there are no issues during transmission,
        # the return value should be true.
        self.assertTrue(lin_transmit, Severity.BLOCKER,
                        "Error when sending a lin message")
